@@ -283,12 +283,15 @@ void Entry::setReadInternal(bool read)
                     m_enclosure->setPlayPosition(0);
                 }
 
-                // 4) Delete episode if that setting is set
+                // 4) Stop download if it's currently running
+                Q_EMIT m_enclosure->cancelDownload();
+
+                // 5) Delete episode if that setting is set
                 if (SettingsManager::self()->autoDeleteOnPlayed() == 1) {
                     m_enclosure->deleteFile();
                 }
             }
-            // 5) Log a sync action to sync this state with (gpodder) server
+            // 6) Log a sync action to sync this state with (gpodder) server
             Sync::instance().storePlayedEpisodeAction(m_id);
         }
     }
@@ -353,8 +356,10 @@ void Entry::setFavoriteInternal(bool favorite)
 
 QString Entry::adjustedContent(int width, int fontSize)
 {
+    static QRegularExpression imgRegex(QStringLiteral("<img ((?!width=\"[0-9]+(px)?\").)*(width=\"([0-9]+)(px)?\")?[^>]*>"));
+    static QRegularExpression imgHeightRegex(QStringLiteral("height=\"([0-9]+)(px)?\""));
+
     QString ret(m_content);
-    QRegularExpression imgRegex(QStringLiteral("<img ((?!width=\"[0-9]+(px)?\").)*(width=\"([0-9]+)(px)?\")?[^>]*>"));
 
     QRegularExpressionMatchIterator i = imgRegex.globalMatch(ret);
     while (i.hasNext()) {
@@ -369,7 +374,7 @@ QString Entry::adjustedContent(int width, int fontSize)
         if (widthParameter.length() != 0) {
             if (widthParameter.toInt() > width) {
                 imgTag.replace(match.captured(3), QStringLiteral("width=\"%1\"").arg(width));
-                imgTag.replace(QRegularExpression(QStringLiteral("height=\"([0-9]+)(px)?\"")), QString());
+                imgTag.replace(imgHeightRegex, QString());
             }
         }
         ret.replace(match.captured(), imgTag);
@@ -380,9 +385,9 @@ QString Entry::adjustedContent(int width, int fontSize)
     // Replace strings that look like timestamps into clickable links with scheme
     // "timestamp://".  We will pick these up in the GUI to work like chapter marks
 
-    QRegularExpression imgRegexDate(QStringLiteral("\\d{1,2}(:\\d{2})+"));
+    static QRegularExpression dateRegex(QStringLiteral("\\d{1,2}(:\\d{2})+"));
 
-    i = imgRegexDate.globalMatch(ret);
+    i = dateRegex.globalMatch(ret);
     while (i.hasNext()) {
         QRegularExpressionMatch match = i.next();
         QString timeStamp(match.captured());
