@@ -66,14 +66,17 @@ MediaPlayer2Player::MediaPlayer2Player(KMediaSession *audioPlayer, bool showProg
         mProgressIndicatorSignal = QDBusMessage::createSignal(newDesktopName, QStringLiteral("com.canonical.Unity.LauncherEntry"), QStringLiteral("Update"));
     });
 
-    if (m_audioPlayer) {
-        m_volume = m_audioPlayer->volume() / 100;
-        signalPropertiesChange(QStringLiteral("Volume"), Volume());
+    // singleShot used here to execute this code after constructor has finished
+    QTimer::singleShot(0, this, [this]() {
+        if (m_audioPlayer) {
+            m_volume = m_audioPlayer->volume() / 100;
+            signalPropertiesChange(QStringLiteral("Volume"), Volume());
 
-        if (!m_audioPlayer->source().isEmpty()) {
-            setSource(m_audioPlayer->source());
+            if (!m_audioPlayer->source().isEmpty()) {
+                setSource(m_audioPlayer->source());
+            }
         }
-    }
+    });
 }
 
 QString MediaPlayer2Player::PlaybackStatus() const
@@ -97,7 +100,8 @@ QString MediaPlayer2Player::PlaybackStatus() const
             parameters.insert(QStringLiteral("progress"), 0);
         } else {
             parameters.insert(QStringLiteral("progress-visible"), true);
-            parameters.insert(QStringLiteral("progress"), qRound(static_cast<double>(m_position / m_audioPlayer->duration())) / 1000.0);
+            parameters.insert(QStringLiteral("progress"),
+                              qRound(static_cast<double>((m_audioPlayer->duration() > 0) ? m_position / m_audioPlayer->duration() : 0)) / 1000.0);
         }
 
         const QString fullDesktopPath = QStringLiteral("application://") + m_audioPlayer->desktopEntryName() + QStringLiteral(".desktop");
@@ -235,7 +239,10 @@ QVariantMap MediaPlayer2Player::Metadata() const
 qlonglong MediaPlayer2Player::Position() const
 {
     qCDebug(Mpris2Log) << "MediaPlayer2Player::Position()";
-    return qlonglong(m_audioPlayer->position()) * 1000;
+    if (m_audioPlayer)
+        return qlonglong(m_audioPlayer->position()) * 1000;
+    else
+        return 0;
 }
 
 double MediaPlayer2Player::Rate() const
@@ -539,7 +546,8 @@ void MediaPlayer2Player::setShowProgressOnTaskBar(bool value)
         parameters.insert(QStringLiteral("progress"), 0);
     } else {
         parameters.insert(QStringLiteral("progress-visible"), true);
-        parameters.insert(QStringLiteral("progress"), qRound(static_cast<double>(m_position / m_audioPlayer->duration())) / 1000.0);
+        parameters.insert(QStringLiteral("progress"),
+                          qRound(static_cast<double>((m_audioPlayer->duration() > 0) ? m_position / m_audioPlayer->duration() : 0)) / 1000.0);
     }
 
     const QString fullDesktopPath = QStringLiteral("application://") + m_audioPlayer->desktopEntryName() + QStringLiteral(".desktop");
