@@ -1,36 +1,35 @@
 /**
- * SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
- * SPDX-FileCopyrightText: 2021 Bart De Vries <bart@mogwai.be>
+ * SPDX-FileCopyrightText: 2020 Tobias Fella <tobias.fella@kde.org>
+ * SPDX-FileCopyrightText: 2021-2023 Bart De Vries <bart@mogwai.be>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #pragma once
 
-#include <QAbstractListModel>
 #include <QHash>
-#include <QItemSelection>
+#include <QModelIndex>
 #include <QObject>
 #include <QVariant>
 
+#include "models/abstractepisodemodel.h"
+
 class Feed;
 
-class EntriesModel : public QAbstractListModel
+class EntriesModel : public AbstractEpisodeModel
 {
     Q_OBJECT
 
-    Q_PROPERTY(Feed *feed READ feed CONSTANT)
-
 public:
     explicit EntriesModel(Feed *feed);
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
-    QHash<int, QByteArray> roleNames() const override;
     int rowCount(const QModelIndex &parent) const override;
 
     Feed *feed() const;
 
-    Q_INVOKABLE QItemSelection createSelection(int rowa, int rowb);
+public Q_SLOTS:
+    void updateInternalState() override;
 
-private:
+protected:
     Feed *m_feed;
 };
