@@ -35,7 +35,9 @@ private:
     QStringList m_entryIds;
     QVector<bool> m_read;
     QVector<bool> m_new;
+    QVector<bool> m_favorite;
     QStringList m_titles;
     QStringList m_contents;
     QStringList m_feedNames;
+    QList<int> m_updated;
 };
