@@ -10,7 +10,6 @@
 #include <QVector>
 
 #include "error.h"
-#include "updatefeedjob.h"
 
 class FetchFeedsJob : public KJob
 {
@@ -33,6 +32,5 @@ private:
     void fetch();
     void monitorProgress();
 
-    QVector<UpdateFeedJob *> m_feedjobs;
     bool m_abort = false;
 };
