@@ -9,66 +9,25 @@
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QNetworkRequest>
+#include <QSqlQuery>
 #include <QString>
 
 #include <Syndication/Syndication>
 #include <ThreadWeaver/Job>
 
-#include "enclosure.h"
+#include "datatypes.h"
+#include "error.h"
 
 class UpdateFeedJob : public QObject, public ThreadWeaver::Job
 {
     Q_OBJECT
 
 public:
-    explicit UpdateFeedJob(const QString &url, const QByteArray &data, QObject *parent = nullptr);
+    explicit UpdateFeedJob(const QString &url, const QByteArray &data, const DataTypes::FeedDetails &feed, QObject *parent = nullptr);
 
     void run(ThreadWeaver::JobPointer, ThreadWeaver::Thread *) override;
     void abort();
 
-    struct EntryDetails {
-        QString feed;
-        QString id;
-        QString title;
-        QString content;
-        int created;
-        int updated;
-        QString link;
-        bool read;
-        bool isNew;
-        bool hasEnclosure;
-        QString image;
-    };
-
-    struct AuthorDetails {
-        QString feed;
-        QString id;
-        QString name;
-        QString uri;
-        QString email;
-    };
-
-    struct EnclosureDetails {
-        QString feed;
-        QString id;
-        int duration;
-        int size;
-        QString title;
-        QString type;
-        QString url;
-        int playPosition;
-        Enclosure::Status downloaded;
-    };
-
-    struct ChapterDetails {
-        QString feed;
-        QString id;
-        int start;
-        QString title;
-        QString link;
-        QString image;
-    };
-
 Q_SIGNALS:
     void feedDetailsUpdated(const QString &url,
                             const QString &name,
@@ -80,30 +39,32 @@ Q_SIGNALS:
     void feedUpdated(const QString &url);
     void entryAdded(const QString &feedurl, const QString &id);
     void entryUpdated(const QString &feedurl, const QString &id);
-    void feedUpdateStatusChanged(const QString &url, bool status);
     void aborting();
     void finished();
+    void error(Error::Type type, const QString &url, const QString &id, const int errorId, const QString &errorString, const QString &title);
 
 private:
     void processFeed(Syndication::FeedPtr feed);
     bool processEntry(Syndication::ItemPtr entry);
     bool processAuthor(const QString &entryId, const QString &authorName, const QString &authorUri, const QString &authorEmail);
-    bool processEnclosure(Syndication::EnclosurePtr enclosure, const EntryDetails &newEntry, const EntryDetails &oldEntry);
+    bool processEnclosure(Syndication::EnclosurePtr enclosure, const DataTypes::EntryDetails &newEntry, const DataTypes::EntryDetails &oldEntry);
     bool processChapter(const QString &entryId, const int &start, const QString &chapterTitle, const QString &link, const QString &image);
     void writeToDatabase();
 
-    QString generateFeedDirname(const QString &name) const;
+    bool dbExecute(QSqlQuery &query);
+    bool dbTransaction();
+    bool dbCommit();
+
+    QString generateFeedDirname(const QString &name);
     bool m_abort = false;
 
     QString m_url;
-    QString m_dirname;
     QByteArray m_data;
-    QString m_oldHash, m_newHash;
 
-    bool m_isNewFeed;
     bool m_markUnreadOnNewFeed;
-    QVector<EntryDetails> m_entries, m_newEntries, m_updateEntries;
-    QVector<AuthorDetails> m_authors, m_newAuthors, m_updateAuthors;
-    QVector<EnclosureDetails> m_enclosures, m_newEnclosures, m_updateEnclosures;
-    QVector<ChapterDetails> m_chapters, m_newChapters, m_updateChapters;
+    DataTypes::FeedDetails m_feed, m_updateFeed;
+    QVector<DataTypes::EntryDetails> m_entries, m_newEntries, m_updateEntries;
+    QVector<DataTypes::AuthorDetails> m_authors, m_newAuthors, m_updateAuthors;
+    QVector<DataTypes::EnclosureDetails> m_enclosures, m_newEnclosures, m_updateEnclosures;
+    QVector<DataTypes::ChapterDetails> m_chapters, m_newChapters, m_updateChapters;
 };
